package workloadforecast

import org.springframework.dao.DataIntegrityViolationException

class ActivityForecastController {

    static allowedMethods = [save: "POST", update: "POST", delete: "POST"]

    def index() {
        redirect(action: "list", params: params)
    }

    def list(Integer max) {
        params.max = Math.min(max ?: 10, 100)
        [activityForecastInstanceList: ActivityForecast.list(params), activityForecastInstanceTotal: ActivityForecast.count()]
    }

    def create() {
        [activityForecastInstance: new ActivityForecast(params)]
    }

    def save() {
        def activityForecastInstance = new ActivityForecast(params)
        if (!activityForecastInstance.save(flush: true)) {
            render(view: "create", model: [activityForecastInstance: activityForecastInstance])
            return
        }

        flash.message = message(code: 'default.created.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), activityForecastInstance.id])
        redirect(action: "show", id: activityForecastInstance.id)
    }

    def show(Long id) {
        def activityForecastInstance = ActivityForecast.get(id)
        if (!activityForecastInstance) {
            flash.message = message(code: 'default.not.found.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "list")
            return
        }

        [activityForecastInstance: activityForecastInstance]
    }

    def edit(Long id) {
        def activityForecastInstance = ActivityForecast.get(id)
        if (!activityForecastInstance) {
            flash.message = message(code: 'default.not.found.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "list")
            return
        }

        [activityForecastInstance: activityForecastInstance]
    }

    def update(Long id, Long version) {
        def activityForecastInstance = ActivityForecast.get(id)
        if (!activityForecastInstance) {
            flash.message = message(code: 'default.not.found.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "list")
            return
        }

        if (version != null) {
            if (activityForecastInstance.version > version) {
                activityForecastInstance.errors.rejectValue("version", "default.optimistic.locking.failure",
                          [message(code: 'activityForecast.label', default: 'ActivityForecast')] as Object[],
                          "Another user has updated this ActivityForecast while you were editing")
                render(view: "edit", model: [activityForecastInstance: activityForecastInstance])
                return
            }
        }

        activityForecastInstance.properties = params

        if (!activityForecastInstance.save(flush: true)) {
            render(view: "edit", model: [activityForecastInstance: activityForecastInstance])
            return
        }

        flash.message = message(code: 'default.updated.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), activityForecastInstance.id])
        redirect(action: "show", id: activityForecastInstance.id)
    }
	
def search() {
		//println params.client
		if (request.method == 'POST') {
			//[activityForecastInstanceList:ActivityForecast.findAllByClientLike('%'+params.client+'%')]
			render(view:'list', 
				model:[ activityForecastInstanceList:
					ActivityForecast.findAllByClientLike
						('%' + params.activityType + '%'), activityForecastInstanceTotal: 10 ])
			}
	}

	

    def delete(Long id) {
        def activityForecastInstance = ActivityForecast.get(id)
        if (!activityForecastInstance) {
            flash.message = message(code: 'default.not.found.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "list")
            return
        }

        try {
            activityForecastInstance.delete(flush: true)
            flash.message = message(code: 'default.deleted.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "list")
        }
        catch (DataIntegrityViolationException e) {
            flash.message = message(code: 'default.not.deleted.message', args: [message(code: 'activityForecast.label', default: 'ActivityForecast'), id])
            redirect(action: "show", id: id)
        }
    }
}
